@@ -6,7 +6,7 @@
 #
 # Setup
 #
-# VERSION: $Id: programme.pm,v 2.07 2015/06/08 17:14:01 stefanb2 Exp $
+# VERSION: $Id: programme.pm,v 2.09 2015/12/06 13:43:07 stefanb2 Exp $
 #
 # INSERT FROM HERE ############################################################
 package fi::programme;
@@ -218,13 +218,32 @@ sub dump {
   #   sub-title:   Pingviinin paluu?!?
   #   description: Amerikkalainen animaatiosarja....
   #
-  elsif ((defined $description)               &&
+  elsif ((defined($description))              &&
 	 (exists $series_description{$title}) &&
 	 (($left, $special, $right) = ($description =~ $match_description))) {
     my $desc_subtitle;
 
-    # Check for "Kausi <season>. Jakso <episode>/<# of episodes>. <sub-title>...."
+    # Check for "Kausi <season>, osa <episode>. <maybe sub-title>...."
     if (my($desc_season, $desc_episode, $remainder) =
+	($description =~ m/^Kausi\s+(\d+),\s+osa\s+(\d+)\.\s*(.*)$/)) {
+	$season  = $desc_season;
+	$episode = $desc_episode;
+
+	# Repeat the above match on remaining description
+	($left, $special, $right) = ($remainder =~ $match_description);
+
+	# Take a guess if we have a episode title in description or not
+	my $words;
+	$words++ while $left =~ /\S+/g;
+	if ($words > 5) {
+	    # More than 5 words probably means no episode title
+	    undef $left;
+	    undef $special;
+	    $right = $remainder;
+	}
+
+    # Check for "Kausi <season>. Jakso <episode>/<# of episodes>. <sub-title>...."
+    } elsif (($desc_season, $desc_episode, $remainder) =
 	($description =~ m,^Kausi\s+(\d+)\.\s+Jakso\s+(\d+)(?:/\d+)?\.\s*(.*)$,)) {
 	$season  = $desc_season;
 	$episode = $desc_episode;
@@ -240,6 +259,7 @@ sub dump {
 
 	# Repeat the above match on remaining description
 	($left, $special, $right) = ($remainder =~ $match_description);
+
     # Check for "<sub-title>. Kausi <season>, <episode>/<# of episodes>...."
     } elsif (($desc_subtitle, $desc_season, $desc_episode, $remainder) =
 	     ($description =~ m!^(.+)\s+Kausi\s+(\d+),\s+(\d+)(?:/\d+)?\.\s*(.*)$!)) {
@@ -251,18 +271,20 @@ sub dump {
 	$right = $remainder;
 	undef $special;
     }
-    unless (defined $special) {
-      # We only remove period from episode title, preserve others
-      $left =~ s/\.$//;
-    } elsif (($left    !~ /\.$/) &&
-	     ($special =~ /^\.\s/)) {
-      # Ignore extraneous period after sentence
-    } else {
-      # Preserve others, e.g. ellipsis
-      $special =~ s/\s+$//;
-      $left    .= $special;
+    if (defined($left)) {
+	unless (defined($special)) {
+	    # We only remove period from episode title, preserve others
+	    $left =~ s/\.$//;
+	} elsif (($left    !~ /\.$/) &&
+		 ($special =~ /^\.\s/)) {
+	    # Ignore extraneous period after sentence
+	} else {
+	    # Preserve others, e.g. ellipsis
+	    $special =~ s/\s+$//;
+	    $left    .= $special;
+	}
+	debug(3, "XMLTV series title '$title' episode '$left'");
     }
-    debug(3, "XMLTV series title '$title' episode '$left'");
     ($subtitle, $description) = ($left, $right);
   }
 
